"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeComponent = makeComponent;
exports.textAreaTemplate = textAreaTemplate;
exports.IonInputTemplate = IonInputTemplate;
exports.plainTextTemplate = plainTextTemplate;
exports.emailTemplate = emailTemplate;
exports.passwordTemplate = passwordTemplate;
exports.VexIonInputNumberTemplate = VexIonInputNumberTemplate;
exports.floatTemplate = floatTemplate;
exports.integerTemplate = integerTemplate;
exports.IonDateTimeComponentTemplate = IonDateTimeComponentTemplate;
exports.dateTimeTemplate = dateTimeTemplate;
exports.timeDateTemplate = timeDateTemplate;
exports.dateTemplate = dateTemplate;
exports.timeTemplate = timeTemplate;
exports.monthTemplate = monthTemplate;
exports.yearTemplate = yearTemplate;
exports.monthYearTemplate = monthYearTemplate;
exports.selectOptionTemplate = selectOptionTemplate;
exports.switchTemplate = switchTemplate;
exports.checkboxTemplate = checkboxTemplate;
function makeComponent(schema, inputContent) {
    const config = schema['x-documentConfig'];
    return `<template>
    <div>
${inputContent}
    </div>
</template>

<script setup lang="ts">
import { ref, defineModel } from 'vue';
import { useVuelidate } from '@vuelidate/core';
import vexlidate from '@/vexlidate';
import ${config.documentName}VuelidateConfig from '@/vexlidate/${config.documentName}.gen';

import { IonLabel, IonModal, IonCheckbox, IonToggle, IonInput, IonSelect, IonSelectOption, IonDatetime, IonDatetimeButton } from '@ionic/vue';
import { vexIonInputAutocomplete, vexIonInputNumber }from '@/components/vexIonInput';

const modelValue = defineModel<any>();
const vexlidator = ref(useVuelidate(${config.documentName}VuelidateConfig, modelValue.value));
</script>
`;
}
;
function textAreaTemplate(key, value) {
    return `
<ion-textarea 
    :error-text="vexlidate.errorText(vexlidator.${key})"
    :class="vexlidate.classes(vexlidator.${key})"
    @ionBlur="vexlidate.onBlur(vexlidator.${key})"
    label-placement="floating"
    fill="outline"
/>`;
}
function IonInputTemplate(key, value, type = "text", inputmode) {
    return `
        <ion-input  
            v-model="modelValue.${key}"
            :label="$t('${key}')"
            type="${type}"${inputmode ? `"\n    inputmode="${inputmode}"` : ""}
            :error-text="vexlidate.errorText(vexlidator.${key})"
            :class="vexlidate.classes(vexlidator.${key})"
            @ionBlur="vexlidate.onBlur(vexlidator.${key})"
            label-placement="floating"
            fill="outline"
        />`;
}
function plainTextTemplate(key, value) {
    return IonInputTemplate(key, value);
}
function emailTemplate(key, value) {
    return IonInputTemplate(key, value, "email");
}
function passwordTemplate(key, value) {
    return IonInputTemplate(key, value, "password");
}
function VexIonInputNumberTemplate(key, value, type) {
    const numType = type === 'number' ? 'float' : type;
    return `
        <vex-ion-input-number
            v-model="modelValue.${key}"
            :label="$t('${key}')"
            :numberType="'${numType}'"
            :decimals="2"
            :error-text="vexlidate.errorText(vexlidator.${key})"
            :class="vexlidate.classes(vexlidator.${key})"
            @ionBlur="vexlidate.onBlur(vexlidator.${key})"
            label-placement="floating"
            fill="outline"
        />`;
}
function floatTemplate(key, value) {
    return VexIonInputNumberTemplate(key, value, "float");
}
function integerTemplate(key, value) {
    return VexIonInputNumberTemplate(key, value, "integer");
}
function IonDateTimeComponentTemplate(key, value, ionDateTimePresentation) {
    return `
        <ion-datetime-button datetime="datetime-${key}"/>
        <ion-modal :keep-contents-mounted="true" class="datetime-modal">
            <ion-datetime 
                v-model="modelValue.${key}"
                :label="$t('${key}')"
                id="datetime-${key}"
                presentation="${ionDateTimePresentation}"
                :error-text="vexlidate.errorText(vexlidator.${key})"
                :class="vexlidate.classes(vexlidator.${key})"
                @ionBlur="vexlidate.onBlur(vexlidator.${key})"
            />
        </ion-modal>`;
}
function dateTimeTemplate(key, value) {
    return IonDateTimeComponentTemplate(key, value, "date-time");
}
function timeDateTemplate(key, value) {
    return IonDateTimeComponentTemplate(key, value, "time-date");
}
function dateTemplate(key, value) {
    return IonDateTimeComponentTemplate(key, value, "date");
}
function timeTemplate(key, value) {
    return IonDateTimeComponentTemplate(key, value, "time");
}
function monthTemplate(key, value) {
    return IonDateTimeComponentTemplate(key, value, "month");
}
function yearTemplate(key, value) {
    return IonDateTimeComponentTemplate(key, value, "year");
}
function monthYearTemplate(key, value) {
    return IonDateTimeComponentTemplate(key, value, "month-year");
}
function selectOptionTemplate(key, value) {
    if (!value.enum) {
        return '';
    }
    const options = value.enum.map((option) => {
        return `\t\t\t<ion-select-option value="${option}">${option}</ion-select-option>`;
    }).join('\n');
    return `
        <ion-select 
            v-model="modelValue.${key}"
            :label="$t('${key}')"
            :placeholder="$t('Select') + $t('${key}')"
            label-placement="floating"
            fill="outline"
            interface="popover"
        >${options}
        </ion-select>`;
}
function switchTemplate(key, value) {
    return `
        <div class="flex justify-between px-2">
            <div>
                <ion-label>{{ $t("${key}") }}</ion-label>
            </div>
            <div>
                <ion-toggle
                    :checked="modelValue.${key}"
                    :error-text="vexlidate.errorText(vexlidator.${key})"
                    :class="vexlidate.classes(vexlidator.${key})"
                    @ionBlur="vexlidate.onBlur(vexlidator.${key})"
                />
            </div>
        </div>`;
}
function checkboxTemplate(key, value) {
    return `
        <ion-checkbox 
            label-placement="end"
            :checked="modelValue.${key}"
            :error-text="vexlidate.errorText(vexlidator.${key})"
            :class="vexlidate.classes(vexlidator.${key})"
            @ionBlur="vexlidate.onBlur(vexlidator.${key})"
        >
            {{ $t("${key}") }}
        </ion-checkbox>`;
}
