// import { useVuelidate } from '@vuelidate/core';
import fs from "fs";
import log from "../utils/logger";

import * as ionForm from "../templates/ionicFormInput.template"

export function generate(jsonSchema: any, outFile: string): void {
    log.process("vuelidate", jsonSchema?.["x-documentConfig"]?.documentName);

    const content = ionForm.makeComponent(jsonSchema, schemaToInputs(jsonSchema));

    log.writing("Ionic Form", outFile);
    return fs.writeFileSync(outFile, content);
}

export function schemaToInputs(schema: any): string {
    const props = schema.properties;
    let form = "";
    Object.keys(props).forEach((key) => {
        const item = props[key];
        form += schemaItemToIonInput(key, item);
    }); 
    return form
}

export function schemaItemToIonInput(key: string, value: { [key: string]: any }) :string {

    let result = "";

    // 0. props
    const xInputType = value["x-inputType"] ? value["x-inputType"] : "";
    const xFormat = value["x-format"] ? value["x-format"] : "";
    const xForeignKey = value["x-foreignKey"] ? value["x-foreignKey"] : "";
    const valType = value.type;

    const TypeString = valType == "string";
    const TypeNumber = valType == "number";
    const TypeBoolean = valType == "boolean";

    // "integer" | "float" | "unixTimestamp"
    const FormatInt = xFormat == "integer";
    const FormatFloat = xFormat == "float";
    const FormatUnixTime = xFormat == "unixTimestamp";


    //inputType 
    // "plainText" | "selectOption" | "currencyCode" | "countryCode" | "integer" | "float" | "number" | "currency" | "datetime" | "date" | "time" 

    if(TypeString){
        switch(xInputType){
            case "textArea": 
                result = ionForm.textAreaTemplate(key, value);
                break;
            // case "currencyCode": 
                // result = ionForm.currencyCodeTemplate(key, value);
                // break;
            // case "countryCode": 
                // result = ionForm.countryTemplate(key, value);
                // break;
            // case "autocomplete": 
                // result = ionForm.selectOptionTemplate(key, value);
                // break;
            case "plainText": 
            default: 
                result = ionForm.plainTextTemplate(key, value);
                break;
        }
    }
    
    else if (TypeNumber){
        switch(xInputType){
            case "datetime": 
                if(FormatUnixTime) { 
                    result = ionForm.dateTimeTemplate(key, value);
                };
                break;

            case "date": 
                if(FormatUnixTime) { 
                    result = ionForm.dateTemplate(key, value);
                };
                break;

            case "time": 
                if(FormatUnixTime) { 
                    result = ionForm.timeTemplate(key, value);
                };
                break;
                
            case "integer": 
                result = ionForm.integerTemplate(key, value);
                break;
                // case "currency": result = ionForm.currencyTemplate(key, value);

            case "float": 
            default: 
                result = ionForm.floatTemplate(key, value);
                break;
        }
    }

    else if (TypeBoolean){
        switch(xInputType){
            case "checkbox": 
                result = ionForm.checkboxTemplate(key, value);
                break;
            case "switch": 
            default: 
                result = ionForm.switchTemplate(key, value);
                break;
        }
    };

    // 3. string (enum) select option
    const inpSelect = Array.isArray(value.enum); //(xInputType == "selectOption" &&
    if (xForeignKey || inpSelect) {
        result = ionForm.selectOptionTemplate(key, value);
    }

    return result;
};

export default {
    generate,
    schemaItemToIonInput
};