import vexlidate from "./generators/vuelidate_jsonSchema";
import vexIonicForm from "./generators/ionicForm";
import path from "path";
import fs from "fs";

export function generate(jsonSchemaDir: string, outputDir: string) {

    const outVexlidate = path.join(outputDir, 'vexlidate');
    const outComponents = path.join(outputDir, 'components');
    const outVexForm = path.join(outComponents, 'vexForm');

    // create output dir
    if ( !fs.existsSync(outputDir))     { fs.mkdirSync(outputDir) };
    if ( !fs.existsSync(outVexlidate))  { fs.mkdirSync(outVexlidate) };
    if ( !fs.existsSync(outComponents)) { fs.mkdirSync(outComponents) };
    if ( !fs.existsSync(outVexForm))    { fs.mkdirSync(outVexForm) };

    // clone component dir "vexIonInput/" to "src/components/vexIonInput/"
    const vexIonInputDir = path.join(__dirname, 'templates/vexIonInput');
    const outVexIonInputDir = path.join(outComponents, 'vexIonInput');
    fs.mkdirSync(outVexIonInputDir);
    fs.readdirSync(vexIonInputDir).forEach((file: string) => {
        const srcFile = vexIonInputDir + '/' + file;
        const outFile = outVexIonInputDir + '/' + file;
        fs.copyFileSync(srcFile, outFile);
    });

    vexlidate.makeFile(outVexlidate);

    fs.readdirSync(jsonSchemaDir).forEach((file: string) => {
        if( !file.endsWith(".json") ){
            return;
        };

        const srcFile = jsonSchemaDir + '/' + file;
        const outVexlidateFile = `${outVexlidate}/${file.replace('.json', '.gen.ts')}`;
        const outVexFormFile = `${outVexForm}/${file.replace('.json', '.gen.vue')}`;

        const jsonSchema = JSON.parse(fs.readFileSync(srcFile, "utf8"));

        vexlidate.generate(jsonSchema, outVexlidateFile);
        vexIonicForm.generate(jsonSchema, outVexFormFile);
    });
    
}
