// import * as ionDateTime from "@ionic/core/dist/types/components/datetime/datetime-interface.d.ts"

// The input component is meant for text type inputs only, 
// "text", 
// "password", 
// "email", 
// "number", 
// "search", 
// "tel",  
// "url"

export function makeComponent(schema: any, inputContent: string) {
    const config = schema['x-documentConfig'];

    return `<template>
    <div>
${inputContent}
    </div>
</template>

<script setup lang="ts">
import { ref, defineModel } from 'vue';
import { useVuelidate } from '@vuelidate/core';
import vexlidate from '@/vexlidate';
import ${config.documentName}VuelidateConfig from '@/vexlidate/${config.documentName}.gen';

import { IonLabel, IonModal, IonCheckbox, IonToggle, IonInput, IonSelect, IonSelectOption, IonDatetime, IonDatetimeButton } from '@ionic/vue';
import { vexIonInputAutocomplete, vexIonInputNumber }from '@/components/vexIonInput';

const modelValue = defineModel<any>();
const vexlidator = ref(useVuelidate(${config.documentName}VuelidateConfig, modelValue.value));
</script>
`;
};


export function textAreaTemplate(key: string, value: { [key: string]: any }): string {
    return `
<ion-textarea 
    :error-text="vexlidate.errorText(vexlidator.${key})"
    :class="vexlidate.classes(vexlidator.${key})"
    @ionBlur="vexlidate.onBlur(vexlidator.${key})"
    label-placement="floating"
    fill="outline"
/>`;
}

export function IonInputTemplate(key: string, value: { [key: string]: any },
    type: 'date' | 'email' | 'number' | 'password' | 'search' | 'tel' | 'text' | 'url' | 'time' | 'week' | 'month' | 'datetime-local' = "text",
    inputmode?: 'none' | 'text' | 'tel' | 'url' | 'email' | 'numeric' | 'decimal' | 'search'
): string {
    return `
        <ion-input  
            v-model="modelValue.${key}"
            :label="$t('${key}')"
            type="${type}"${inputmode ? `"\n    inputmode="${inputmode}"` : ""}
            :error-text="vexlidate.errorText(vexlidator.${key})"
            :class="vexlidate.classes(vexlidator.${key})"
            @ionBlur="vexlidate.onBlur(vexlidator.${key})"
            label-placement="floating"
            fill="outline"
        />`;
}

export function plainTextTemplate(key: string, value: { [key: string]: any }): string {
    return IonInputTemplate(key, value);
}

export function emailTemplate(key: string, value: { [key: string]: any }): string {
    return IonInputTemplate(key, value, "email");
}

export function passwordTemplate(key: string, value: { [key: string]: any }): string {
    return IonInputTemplate(key, value, "password");
}

// number
export function VexIonInputNumberTemplate(key: string, value: { [key: string]: any }, type: 'float' | 'number' | 'integer'): string {
    const numType: 'integer' | 'float' = type === 'number' ? 'float' : type;
    return `
        <vex-ion-input-number
            v-model="modelValue.${key}"
            :label="$t('${key}')"
            :numberType="'${numType}'"
            :decimals="2"
            :error-text="vexlidate.errorText(vexlidator.${key})"
            :class="vexlidate.classes(vexlidator.${key})"
            @ionBlur="vexlidate.onBlur(vexlidator.${key})"
            label-placement="floating"
            fill="outline"
        />`;
}

export function floatTemplate(key: string, value: { [key: string]: any }): string {
    return VexIonInputNumberTemplate(key, value, "float");
}

export function integerTemplate(key: string, value: { [key: string]: any }): string {
    return VexIonInputNumberTemplate(key, value, "integer");
}


// ion-date-time 
// import { DatetimePresentation } 
// from "@ionic\core\dist\types\components\datetime\datetime-interface.d.ts"
// 'date-time' | 'time-date' | 'date' | 'time' | 'month' | 'year' | 'month-year';

export function IonDateTimeComponentTemplate(key: string, value: any, ionDateTimePresentation: any) { //ionDateTime.DatetimePresentation){
    return `
        <ion-datetime-button datetime="datetime-${key}"/>
        <ion-modal :keep-contents-mounted="true" class="datetime-modal">
            <ion-datetime 
                v-model="modelValue.${key}"
                :label="$t('${key}')"
                id="datetime-${key}"
                presentation="${ionDateTimePresentation}"
                :error-text="vexlidate.errorText(vexlidator.${key})"
                :class="vexlidate.classes(vexlidator.${key})"
                @ionBlur="vexlidate.onBlur(vexlidator.${key})"
            />
        </ion-modal>`
}

export function dateTimeTemplate(key: string, value: { [key: string]: any }): string {
    return IonDateTimeComponentTemplate(key, value, "date-time");
}
export function timeDateTemplate(key: string, value: { [key: string]: any }): string {
    return IonDateTimeComponentTemplate(key, value, "time-date");
}
export function dateTemplate(key: string, value: { [key: string]: any }): string {
    return IonDateTimeComponentTemplate(key, value, "date");
}
export function timeTemplate(key: string, value: { [key: string]: any }): string {
    return IonDateTimeComponentTemplate(key, value, "time");
}
export function monthTemplate(key: string, value: { [key: string]: any }): string {
    return IonDateTimeComponentTemplate(key, value, "month");
}
export function yearTemplate(key: string, value: { [key: string]: any }): string {
    return IonDateTimeComponentTemplate(key, value, "year");
}
export function monthYearTemplate(key: string, value: { [key: string]: any }): string {
    return IonDateTimeComponentTemplate(key, value, "month-year");
}

// others

export function selectOptionTemplate(key: string, value: { [key: string]: any }): string {
    if(!value.enum){
        return '';
    }
    const options = value.enum.map((option: string) => {
        return `\t\t\t<ion-select-option value="${option}">${option}</ion-select-option>`;
    }).join('\n');
    return `
        <ion-select 
            v-model="modelValue.${key}"
            :label="$t('${key}')"
            :placeholder="$t('Select') + $t('${key}')"
            label-placement="floating"
            fill="outline"
            interface="popover"
        >${options}
        </ion-select>`;
}

export function switchTemplate(key: string, value: { [key: string]: any }): string {
    return `
        <div class="flex justify-between px-2">
            <div>
                <ion-label>{{ $t("${key}") }}</ion-label>
            </div>
            <div>
                <ion-toggle
                    :checked="modelValue.${key}"
                    :error-text="vexlidate.errorText(vexlidator.${key})"
                    :class="vexlidate.classes(vexlidator.${key})"
                    @ionBlur="vexlidate.onBlur(vexlidator.${key})"
                />
            </div>
        </div>`;
}


export function checkboxTemplate(key: string, value: { [key: string]: any }): string {
    return `
        <ion-checkbox 
            label-placement="end"
            :checked="modelValue.${key}"
            :error-text="vexlidate.errorText(vexlidator.${key})"
            :class="vexlidate.classes(vexlidator.${key})"
            @ionBlur="vexlidate.onBlur(vexlidator.${key})"
        >
            {{ $t("${key}") }}
        </ion-checkbox>`;
}